@@ -1,5 +1,5 @@
 package DBIx::Perlish::Parse;
-# $Id: Parse.pm,v 1.96 2009/01/09 15:52:45 tobez Exp $
+# $Id: Parse.pm,v 1.97 2009/02/16 12:08:49 tobez Exp $
 use 5.008;
 use warnings;
 use strict;
@@ -1474,6 +1474,9 @@ sub compile_conditionally
 			# conditional returns are nice
 			parse_return($S, $op);
 			return ();
+		} elsif (is_listop($op, "leave") || is_listop($op, "scope")) {
+			parse_list($S, $op);
+			return ();
 		} else {
 			return scalar parse_term($S, $op);
 		}
@@ -1702,6 +1705,10 @@ sub parse_op
 		$S->{limit} = 1;
 	} elsif (is_op($op, "pushmark")) {
 		# skip
+	} elsif (is_op($op, "enter")) {
+		# skip
+	} elsif (is_op($op, "null")) {
+		# skip
 	} elsif (is_cop($op, "nextstate")) {
 		$S->{file} = $op->file;
 		$S->{line} = $op->line;
